/*
  Image Puzzle - A set your pieces straight game
  Copyright (C) 2009  Timo Härkönen

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DEFINES_H
#define DEFINES_H

#define IMAGE_WIDTH 600

#define IMAGE_HEIGHT 400

#define EASY_PIECE_COUNT 9
#define EASY_HORIZONTAL_COUNT 3
#define HARD_PIECE_COUNT 16
#define HARD_HORIZONTAL_COUNT 4

#define DEFAULT_IMAGE_TXT "Default image"
#define RANDOM_IMAGE_TXT "Random image"
#define SELECT_IMAGE_TXT "Select image..."

#define RESTORE_FILE "impuzzle.dat"
#define STATS_FILE "imstats.dat"
#define HOME_DIRECTORY ".impuzzle"

#define IMPUZZLE_VERSION "0.7"

#endif // DEFINES_H
